@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-import logging
 import os.path
 
 import click
@@ -17,13 +16,10 @@ from inforion.helper.filehandling import *
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
 from inforion.ionapi.model import inforlogin
+from inforion.logger.logger import get_logger
 from inforion.messaging.messaging import post_messaging_v2_multipart_message
 
-# from logger import get_logger
-
-# TODO update to use multi modules log
-logging.basicConfig(level=logging.INFO)
-logger = logging.getLogger("main")
+logger = get_logger("main")
 
 
 @click.group()
