@@ -18,7 +18,8 @@ from requests.auth import HTTPBasicAuth
 from oauthlib.oauth2 import BackendApplicationClient
 
 import logging
-#from logger import get_logger
+
+# from logger import get_logger
 
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
@@ -163,11 +164,10 @@ def executeSnd(
     df = df.astype(str)
 
     if outputfile is not None:
-        logging.info('Save to file: ' + outputfile)
-        filehandling.savetodisk(outputfile,df)
-    
-    return df
+        logging.info("Save to file: " + outputfile)
+        filehandling.savetodisk(outputfile, df)
 
+    return df
 
     logging.info("Still in Beta")
 
@@ -211,28 +211,22 @@ def executeSnd(
         index = index + 1
         # df,data,chunk = saveresults(r,df,methode,index,chunk)
 
-  
-
     logging.info(r)
 
-  
-
-    df = df.replace(np.nan, '', regex=True)
+    df = df.replace(np.nan, "", regex=True)
     df = df.astype(str)
-    
-    if outputfile is not None:
-        print ('Save to file: ' + outputfile)
-        filehandling.savetodisk(outputfile,df)
-    
-    return df
 
-   
+    if outputfile is not None:
+        print("Save to file: " + outputfile)
+        filehandling.savetodisk(outputfile, df)
+
+    return df
 
 
 def getSuccessGraphDataframe(df):
     results = {}
     for _, row in df.iterrows():
-        msgs = row["MESSAGE"].split("|")
+        msgs = row["MESSAGE"].split("^_^")
         for msg in msgs:
             if msg:
                 key = msg[0 : msg.index(":")]
@@ -287,8 +281,6 @@ def createGraph(excel_file, df):
     chart1.shape = 4
     chart1.height = 12
     chart1.width = 20
-    # chart1.x_axis = 10
-    # chart1.y_axis = 10
 
     ws_graph.add_chart(chart1, "A10")
     writer.save()
